@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -98,7 +98,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         final int intArray[] = {};
         final String stringArray[] = {};
 
-        final DynaClass dynaClass = new BasicDynaClass
+        return new BasicDynaClass
                 ("TestDynaClass", null,
                         new DynaProperty[]{
                             new DynaProperty("booleanProperty", Boolean.TYPE),
@@ -122,7 +122,6 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             new DynaProperty("stringIndexed", stringArray.getClass()),
                             new DynaProperty("stringProperty", String.class),
                         });
-        return dynaClass;
 
     }
 
@@ -1425,8 +1424,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             fail("InvocationTargetException");
         } catch (final NoSuchMethodException e) {
             // Correct result for this test
-            assertEquals("Unknown property 'unknown' on dynaclass '" +
-                         bean.getDynaClass() + "'", e.getMessage() );
+            assertEquals("Unknown property 'unknown' on dynaclass '" + bean.getDynaClass() + "'", e.getMessage());
         }
 
     }
@@ -2514,12 +2512,8 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         try {
             final String oldValue = (String) bean.get("stringProperty");
             final String newValue = oldValue + " Extra Value";
-            PropertyUtils.setSimpleProperty(bean,
-                    "stringProperty",
-                    newValue);
-            assertEquals("Matched new value",
-                    newValue,
-                    (String) bean.get("stringProperty"));
+            PropertyUtils.setSimpleProperty(bean, "stringProperty", newValue);
+            assertEquals("Matched new value", newValue, (String) bean.get("stringProperty"));
         } catch (final IllegalAccessException e) {
             fail("IllegalAccessException");
         } catch (final IllegalArgumentException e) {
@@ -2539,9 +2533,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
 
         try {
             final String newValue = "New String Value";
-            PropertyUtils.setSimpleProperty(bean,
-                    "unknown",
-                    newValue);
+            PropertyUtils.setSimpleProperty(bean, "unknown", newValue);
             fail("Should have thrown NoSuchMethodException");
         } catch (final IllegalAccessException e) {
             fail("IllegalAccessException");
@@ -2551,8 +2543,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             fail("InvocationTargetException");
         } catch (final NoSuchMethodException e) {
             // Correct result for this test
-            assertEquals("Unknown property 'unknown' on dynaclass '" +
-                         bean.getDynaClass() + "'", e.getMessage() );
+            assertEquals("Unknown property 'unknown' on dynaclass '" + bean.getDynaClass() + "'", e.getMessage());
         }
 
     }
